package com.ruoyi.szxc.service;

import java.util.List;
import com.ruoyi.szxc.domain.SzxcSbzl;

/**
 * 上报资料Service接口
 * 
 * @author hs
 * @date 2024-03-20
 */
public interface ISzxcSbzlService 
{
    /**
     * 查询上报资料
     * 
     * @param id 上报资料主键
     * @return 上报资料
     */
    public SzxcSbzl selectSzxcSbzlById(Long id);

    /**
     * 查询上报资料列表
     * 
     * @param szxcSbzl 上报资料
     * @return 上报资料集合
     */
    public List<SzxcSbzl> selectSzxcSbzlList(SzxcSbzl szxcSbzl);

    /**
     * 新增上报资料
     * 
     * @param szxcSbzl 上报资料
     * @return 结果
     */
    public int insertSzxcSbzl(SzxcSbzl szxcSbzl);

    /**
     * 修改上报资料
     * 
     * @param szxcSbzl 上报资料
     * @return 结果
     */
    public int updateSzxcSbzl(SzxcSbzl szxcSbzl);

    /**
     * 批量删除上报资料
     * 
     * @param ids 需要删除的上报资料主键集合
     * @return 结果
     */
    public int deleteSzxcSbzlByIds(Long[] ids);

    /**
     * 删除上报资料信息
     * 
     * @param id 上报资料主键
     * @return 结果
     */
    public int deleteSzxcSbzlById(Long id);
}
